@@ -14,16 +14,17 @@ from django.core.management import call_command
 from django.db.models import get_apps
 from django.test import TransactionTestCase
 
-ERROR_TEXT = u'line={0}, file={1}, url={2}, post_params={3}'
-
-if django.VERSION[:3] > (1, 6, 0) and getattr(settings, 'SMOKNUR_NEW_DJANGO_TESTCASE', True):
+if (django.VERSION[:3] > (1, 6, 0) and
+        getattr(settings, 'SMOKNUR_NEW_DJANGO_TESTCASE', True)):
     NEW_DJANGO_TESTCASE = True
 else:
     NEW_DJANGO_TESTCASE = False
 
+
 def _fixture_setup(self):
     """
-    начиная с джанги 1.6, в данном методе отсутсвует вызов метода call_command('flush')
+    начиная с джанги 1.6, в данном методе отсутсвует вызов метода
+    call_command('flush')
     поэтому выполняем данный загрузчик фикстур
     """
     for db_name in self._databases_names(include_mirrors=False):
@@ -41,6 +42,7 @@ def _fixture_setup(self):
                          **{'verbosity': 0, 'database': db_name,
                             'skip_validation': True})
 
+
 def test_runner(self):
     """smoke test"""
 
@@ -62,7 +64,8 @@ def test_runner(self):
 
                         if getattr(settings, 'SMOKNUR_PRINT_REQUESTS', False):
                             sys.stdout.write(
-                                u'line={0}, file={1}, url={2}, post_params={3}'.format(
+                                u'line={0}, file={1}, url={2}, '
+                                u'post_params={3}'.format(
                                     index,
                                     f,
                                     req['url'],
@@ -75,15 +78,20 @@ def test_runner(self):
                             )
                         except:
                             sys.stdout.write(
-                                u'line={0}, file={1}, url={2}, post_params={3}'.format(
+                                u'line={0}, file={1}, url={2}, '
+                                u'post_params={3}'.format(
                                     index,
                                     f,
                                     req['url'],
                                     req['params']).encode('utf-8'))
                             raise
                         else:
-                            if getattr(settings, 'SMOKNUR_PRINT_RESPONSE', False):
-                                size = getattr(settings, 'SMOKNUR_PRINT_RESPONSE_SIZE', 0)
+                            if getattr(settings,
+                                       'SMOKNUR_PRINT_RESPONSE',
+                                       False):
+                                size = getattr(settings,
+                                               'SMOKNUR_PRINT_RESPONSE_SIZE',
+                                               0)
                                 sys.stdout.write(
                                     u'{0}, {1}\n'.format(
                                         resp.status_code,
@@ -91,7 +99,8 @@ def test_runner(self):
 
                         self.assertTrue(
                             resp.status_code in (200, 302),
-                            u'line={0}, file={1}, url={2}, post_params={3}, status_code={4}'.format(
+                            u'line={0}, file={1}, url={2}, post_params={3}, '
+                            u'status_code={4}'.format(
                                 index,
                                 f,
                                 req['url'],
@@ -110,7 +119,6 @@ for app in get_apps():
         os.path.dirname(app.__file__),
         'smoknur')
 
-
     if os.path.exists(path):
 
         smok_dirs = [
